#!/usr/bin/python3
# -*- coding: utf-8 -*-

import pytest


@pytest.hookspec(firstresult=True)
def pytest_send_upload_request(upload_url: str, files: list, config: dict):
    """ send upload request """



import requests
import time
from hashlib import md5


class UploadClient(object):
    def __init__(self, upload_url, files):
        self.upload_url = upload_url
        self.files = files

    def send_request(self, data=None, _json=None, params={}, headers={}):
        multiple_files = []
        for _file in self.files:
            multiple_files.append(('files', open(_file, 'rb'), ))
        return requests.post(
            self.upload_url,
            data=data,
            json=_json,
            params=params,
            files=multiple_files,
            headers=headers
        )


class SignUploadClient(UploadClient):
    def send_request(self, config={}):
        params = {  # noqa
            'project_id': config.get('upload_project_id', ''),
            'timestamp': str(int(time.time())),
            'username': config.get('upload_username', '')
        }
        hash_str = f'project_id={params["project_id"]}&timestamp={params["timestamp"]}&username={params["username"]}'
        secret = config.get('upload_secret', '')
        sign = md5((hash_str + secret).encode('utf-8')).hexdigest().upper()
        headers = {'sign': sign}
        response = super().send_request(params=params, headers=headers)
        if response.status_code != 200:
            raise Exception(response.text)



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import io
import os
import sys
import json
import uuid
import shutil
from six import text_type
from attr import asdict
from allure_commons import hookimpl
from allure_commons.logger import AllureFileLogger, INDENT


class AllureFileUploadLogger(AllureFileLogger):

    def __init__(self, report_dir, clean=False):
        super().__init__(report_dir, clean)
        self.report_files = []

    def _report_item(self, item):
        indent = INDENT if os.environ.get("ALLURE_INDENT_OUTPUT") else None
        filename = item.file_pattern.format(prefix=uuid.uuid4())
        data = asdict(item, filter=lambda attr, value: not (type(value) != bool and not bool(value)))
        with io.open(os.path.join(self._report_dir, filename), 'w', encoding='utf8') as json_file:
            if sys.version_info.major < 3:
                json_file.write(
                    unicode(json.dumps(data, indent=indent, ensure_ascii=False, encoding='utf8')))  # noqa: F821
            else:
                json.dump(data, json_file, indent=indent, ensure_ascii=False)
        self.report_files.append(filename)

    @hookimpl(tryfirst=True)
    def report_result(self, result):
        self._report_item(result)
        return False

    @hookimpl(tryfirst=True)
    def report_container(self, container):
        self._report_item(container)
        return False

    @hookimpl(tryfirst=True)
    def report_attached_file(self, source, file_name):
        destination = os.path.join(self._report_dir, file_name)
        shutil.copy2(source, destination)
        self.report_files.append(file_name)
        return False

    @hookimpl(tryfirst=True)
    def report_attached_data(self, body, file_name):
        destination = os.path.join(self._report_dir, file_name)
        with open(destination, 'wb') as attached_file:
            if isinstance(body, text_type):
                attached_file.write(body.encode('utf-8'))
            else:
                attached_file.write(body)
        self.report_files.append(file_name)
        return False



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import os
import os.path
import pytest


def pytest_addhooks(pluginmanager):
    from . import hooks
    pluginmanager.add_hookspecs(hooks)


def pytest_addoption(parser):
    group = parser.getgroup('upload_report')
    group.addoption('--upload_url', action='store', dest='upload_url', default='')
    group.addoption('--upload_project_id', action='store', dest='upload_project_id', default='')
    group.addoption('--upload_secret', action='store', dest='upload_secret', default='')
    group.addoption('--upload_username', action='store', dest='upload_username', default='')


def pytest_configure(config):
    allure_plugin = config.pluginmanager.get_plugin("allure_pytest")
    if allure_plugin:
        report_dir = config.option.allure_report_dir
        if report_dir:
            import allure_commons
            from allure_pytest.plugin import cleanup_factory
            from .allure_upload import AllureFileUploadLogger
            from allure_commons.logger import AllureFileLogger

            # 卸载原有的AllureFileLogger插件，并还原cleanup
            plugin_list = []
            for plugin in allure_commons.plugin_manager.get_plugins():
                if isinstance(plugin, AllureFileLogger):
                    allure_commons.plugin_manager.unregister(plugin)
                    cleanup_list = []
                    for i, clean_item in enumerate(config._cleanup):
                        if clean_item.__module__ == 'allure_pytest.plugin' and clean_item.__name__ == 'clean_up':
                            continue
                        else:
                            cleanup_list.append(clean_item)
                    config._cleanup = cleanup_list
                else:
                    plugin_list.append(plugin)
            clean = config.option.clean_alluredir
            file_upload_logger = AllureFileUploadLogger(report_dir, clean)
            allure_commons.plugin_manager.register(file_upload_logger, 'allure_file_upload_logger')
            plugin_list.append(file_upload_logger)
            for plugin in plugin_list:
                config.add_cleanup(cleanup_factory(plugin))

    html_plugin = config.pluginmanager.get_plugin("html")
    if html_plugin:
        report_dir = config.option.htmlpath
        if report_dir:
            pass


def pytest_sessionfinish(session, exitstatus):
    allure_plugin = session.config.pluginmanager.get_plugin("allure_pytest")
    if allure_plugin:
        report_dir = session.config.option.allure_report_dir
        if report_dir:
            import allure_commons
            plugin = allure_commons.plugin_manager.get_plugin('allure_file_upload_logger')
            files = []
            for report_file in plugin.report_files:
                files.append(os.path.join(report_dir, report_file))
            session.config.hook.pytest_send_upload_request(
                upload_url=session.config.option.upload_url,
                files=files,
                config=session.config.option.__dict__,
            )

    html_plugin = session.config.pluginmanager.get_plugin("html")
    if html_plugin:
        report_dir = session.config.option.htmlpath
        if report_dir:
            pass


@pytest.hookimpl
def pytest_send_upload_request(upload_url, files, config):
    from .upload_client import UploadClient
    client = UploadClient(upload_url, files)
    client.send_request()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding='utf-8').read()


setup(
    name='pytest-upload-report',
    version='0.1.0',
    author='Anna',
    author_email='191996155@qq.com',
    maintainer='Anna',
    maintainer_email='191996155@qq.com',
    license='MIT',
    url='https://github.com/tim2anna/pytest-upload-report',
    description='pytest-upload-report is a plugin for pytest that upload your test report for test results.',
    long_description_content_type="text/x-rst",
    long_description=read('README.rst'),
    packages=["pytest_upload_report"],
    keywords="py.test pytest report allure upload",
    python_requires='>=3.7',
    install_requires=['pytest>=6.2.4', 'requests>=2.25.1', 'allure-pytest>=2.9.43', 'pytest-html>=3.1.1'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Pytest',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Testing',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points={
        'pytest11': [
            'upload_report = pytest_upload_report.plugin',
        ],
    },
)
